'use strict';

async function disableIncognito(tab) {
    if (tab.incognito) {
        // this does not work, it seems that the browser action is re-enabled
        // on every update
        await browser.browserAction.disable(tab.id);
        let isEnabled = await browser.browserAction.isEnabled({tabId: tab.id});
        console.log(`tab ${tab.id} isEnabled: ${isEnabled}`);
    }
}

// disable the browser action for new incognito tabs
browser.tabs.onCreated.addListener(disableIncognito);
browser.tabs.onUpdated.addListener(async (tabId, changeInfo, tab) => {
    let isEnabled = await browser.browserAction.isEnabled({tabId: tab.id});
    console.log(`tab ${tab.id} isEnabled: ${isEnabled}`);
});

(async () => {
    // disable the browser action for existing incognito tabs
    let tabs = await browser.tabs.query({});
    await Promise.all(tabs.filter(tab => tab.incognito)
            .map(tab => browser.browserAction.disable(tab.id)))
    for (let tab of tabs) {
        let isEnabled = await browser.browserAction.isEnabled({tabId: tab.id});
        console.log(`tab ${tab.id} isEnabled: ${isEnabled}`);
    }
})();
